@@ -1,7 +1,7 @@
 package File::Trash::Undoable;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.17'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.18'; # VERSION
 
 use 5.010001;
 use strict;
@@ -243,7 +243,7 @@ File::Trash::Undoable - Trash files, with undo/redo capability
 
 =head1 VERSION
 
-This document describes version 0.17 of File::Trash::Undoable (from Perl distribution File-Trash-Undoable), released on 2015-08-17.
+This document describes version 0.18 of File::Trash::Undoable (from Perl distribution File-Trash-Undoable), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -261,7 +261,7 @@ Screenshots:
 
 =head2 empty_trash() -> [status, msg, result, meta]
 
-{en_US Empty trash}.
+Empty trash.
 
 No arguments.
 
@@ -279,7 +279,7 @@ Return value:  (any)
 
 =head2 list_trash_contents() -> [status, msg, result, meta]
 
-{en_US List contents of trash directory}.
+List contents of trash directory.
 
 No arguments.
 
@@ -297,13 +297,11 @@ Return value:  (any)
 
 =head2 trash(%args) -> [status, msg, result, meta]
 
-{en_US Trash a file}.
+Trash a file.
 
-{en_US 
 Fixed state: path does not exist.
 
 Fixable state: path exists.
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -358,7 +356,7 @@ Return value:  (any)
 
 =head2 trash_files(%args) -> [status, msg, result, meta]
 
-{en_US Trash files (with undo support)}.
+Trash files (with undo support).
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -369,11 +367,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<files>* => I<array[str]>
 
-{en_US Files/dirs to delete}.
+Files/dirs to delete.
 
-{en_US 
 Files must exist.
-}
 
 =back
 
@@ -417,14 +413,12 @@ Return value:  (any)
 
 =head2 untrash(%args) -> [status, msg, result, meta]
 
-{en_US Untrash a file}.
+Untrash a file.
 
-{en_US 
 Fixed state: path exists.
 
 Fixable state: Path does not exist (and exists in trash, and if suffix is
 specified, has the same suffix).
-}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -504,7 +498,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-Trash
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-File-Trash-Undoable>.
+Source repository is at L<https://github.com/perlancar/perl-File-Trash-Undoable>.
 
 =head1 BUGS
 
